import brackets
import tournaments


def main():
    # 224997
    # print(brackets.sets_played_by_player(225024, "DOM"))
    # print(brackets.sets_played_by_player(224997, "DOM"))
    print(tournaments.show_player_sets('hidden-bosses-4-0', 'DOM'))
    # print(tournaments.show('hidden-bosses-4-0'))
    # print(tournaments.show_sets('hidden-bosses-4-0'))
    # print(tournaments.show_players('hidden-bosses-4-0'))

if __name__ == "__main__":

    main()
